import React, { useState } from "react";
import { useLocation, useNavigate } from "react-router-dom";
import "./SearchResults.css"; // Ensure to import the CSS file
import axios from "axios";

const SearchResults = () => {
  const location = useLocation();
  const navigate = useNavigate();
  const initialUsers = location.state?.users || []; // Get users from state
  const [users, setUsers] = useState(initialUsers); // State to manage users
  const [editingUser, setEditingUser] = useState(null); // State to manage the user being edited
  const [formData, setFormData] = useState({}); // State to hold form data for the user
  const [firstName, setFirstName] = useState("");  // State for first name input
  const [lastName, setLastName] = useState("");   // State for last name input
  const [userData, setUserData] = useState({ name: "", email: "" });
  const [middleName, setMiddleName] = useState("");
  const [suffix, setSuffix] = useState("");
  const [maidenName, setMaidenName] = useState("");
  const [nickname, setNickname] = useState("");
  const [gender, setGender] = useState("");
  const [techAlumChapter, setTechAlumChapter] = useState("");
  const [classYear, setClassYear] = useState("");
  const [gradYear, setGradYear] = useState("");
  const [gradSemester, setGradSemester] = useState("");
  const [subject, setSubject] = useState("");
  const [degreeType, setDegreeType] = useState("");
  const [degreeYear, setDegreeYear] = useState("");
  const [degreeDescription, setDegreeDescription] = useState("");
  const [degreeDepartment, setDegreeDepartment] = useState("");
  const [degreeCollege, setDegreeCollege] = useState("");
  const [address1, setAddress1] = useState("");
  const [address2, setAddress2] = useState("");
  const [city, setCity] = useState("");
  const [state, setState] = useState("");
  const [country, setCountry] = useState("");
  const [zipCode, setZipCode] = useState("");
  const [preferredAddress, setPreferredAddress] = useState(false);
  const [contactNumber, setContactNumber] = useState("");
  const [contactType, setContactType] = useState("");
  const [preferredContact, setPreferredContact] = useState(false);
  const [involvements, setInvolvements] = useState("");

  const handleBackClick = () => {
    navigate(-1); // Navigate back to the previous page
  };

  const handleDeleteUser = (userId) => {
    const confirmDelete = window.confirm("Are you sure you want to delete this user?");
    if (confirmDelete) {
      // Make the API request to delete the user
      const config = {
        method: 'delete',
        url: `${process.env.REACT_APP_API_URL}./components/SearchResults/SearchResults`, // Adjust the URL as needed for your API
        headers: {
          'Content-Type': 'application/json'
        }
      };
  
      axios.request(config)
        .then((response) => {
          console.log(`User with ID ${userId} deleted`, response.data);
          // Update local state to reflect the deleted user
          setUsers((prevUsers) => prevUsers.filter(user => user.id !== userId));
        })
        .catch((error) => {
          console.error("There was an error deleting the user!", error);
        });
    } else {
      console.log("User deletion canceled");
    }
  };

  // this function pre populates the form with the database information when update is clicked using the use states above
  const handleUpdateUser = (userId) => {
    const userToUpdate = users.find(user => user.id === userId);
    setEditingUser(userToUpdate);
    setFormData({ ...userToUpdate }); // Populate the form data with the user's current information
  };

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setFormData((prevData) => ({ ...prevData, [name]: value }));
  };

  //this function updates all the user information for whatever the user change onces the update user button is clicked
  const handleUpdateSubmit = (e) => {
    e.preventDefault();

    // Construct the data object for the API call
    const updatedData = {
      personInfo: {
        peopleId: editingUser.id, // Assuming the ID corresponds to peopleId
        firstName,
        lastName,
        middleName,
        maidenName,
        suffix,
        nickName: nickname,
        techAlumniChapter: techAlumChapter,
        classYear,
        gradYear,
        gradSemester,
        gender
      },
      //degrees, // Assuming you manage this state elsewhere in your component
      //addresses, // Assuming you manage this state elsewhere in your component
      contacts: [], // Update as needed based on your form
      involvements: involvements.split(",").map(item => item.trim()) // Split by commas to create an array
    };

    const config = {
      method: 'put',
      maxBodyLength: Infinity,
      url: `${process.env.REACT_APP_API_URL}./components/SearchResults/SearchResults`,
      headers: {
        'Content-Type': 'application/json'
      },
      data: JSON.stringify(updatedData) // Stringify the updated data
    };

    // Make the API request
    axios.request(config)
      .then((response) => {
        console.log(JSON.stringify(response.data));
        // Update users state after a successful API call
        setUsers((prevUsers) =>
          prevUsers.map((user) => (user.id === editingUser.id ? { ...updatedData.personInfo } : user))
        );
        setEditingUser(null); // Close the form after updating
      })
      .catch((error) => {
        console.log(error);
      });
  };

  return (
    <div className="search-results-container">
      <h2>Search Results</h2>
      <button onClick={handleBackClick}>← Back</button>
      {editingUser ? (
        <form onSubmit={handleUpdateSubmit}>
          <h3>Update User</h3>
          <label>
            First Name:
            <input type="text" name="firstName" value={firstName} onChange={handleInputChange} required />
          </label>
          <label>
            Last Name:
            <input type="text" name="lastName" value={lastName} onChange={handleInputChange} required />
          </label>
          <label>
            Middle Name:
            <input type="text" name="middleName" value={middleName} onChange={handleInputChange} />
          </label>
          <label>
            Suffix:
            <input type="text" name="suffix" value={suffix} onChange={handleInputChange} />
          </label>
          <label>
            Maiden Name:
            <input type="text" name="maidenName" value={maidenName} onChange={handleInputChange} />
          </label>
          <label>
            Nickname:
            <input type="text" name="nickname" value={nickname} onChange={handleInputChange} />
          </label>
          <label>
            Gender:
            <input type="text" name="gender" value={gender} onChange={handleInputChange} />
          </label>
          <label>
            Tech Alum Chapter:
            <input type="text" name="techAlumChapter" value={techAlumChapter} onChange={handleInputChange} />
          </label>
          <label>
            Class Year:
            <input type="number" name="classYear" value={classYear} onChange={handleInputChange} required />
          </label>
          <label>
            Grad Year:
            <input type="number" name="gradYear" value={gradYear} onChange={handleInputChange} required />
          </label>
          <label>
            Grad Semester:
            <input type="text" name="gradSemester" value={gradSemester} onChange={handleInputChange} />
          </label>
          <button type="submit">Update User</button>
          <button type="button" onClick={() => setEditingUser(null)}>Cancel</button>
        </form>
      ) : users.length > 0 ? (
        <table className="search-results-table">
          <thead>
            <tr>
              <th>ID</th>
              <th>First Name</th>
              <th>Last Name</th>
              <th>Middle Name</th>
              <th>Suffix</th>
              <th>Maiden Name</th>
              <th>Nickname</th>
              <th>Gender</th>
              <th>Tech Alum Chapter</th>
              <th>Class Year</th>
              <th>Grad Year</th>
              <th>Grad Semester</th>
              <th>Degrees</th>
              <th>Addresses</th>
              <th>Contacts</th>
              <th>Involvements</th>
              <th>Actions</th> {/* Added Actions header */}
            </tr>
          </thead>
          <tbody>
            {users.map((user) => (
              <tr key={user.id}>
                <td>{user.id}</td>
                <td>{user.firstName}</td>
                <td>{user.lastName}</td>
                <td>{user.middleName}</td>
                <td>{user.suffix}</td>
                <td>{user.maidenName}</td>
                <td>{user.nickname}</td>
                <td>{user.gender}</td>
                <td>{user.techAlumChapter}</td>
                <td>{user.classYear}</td>
                <td>{user.gradYear}</td>
                <td>{user.gradSemester}</td>
                <td>
                  {user.degrees.map((degree, index) => (
                    <div key={index}>
                      {degree.degreeType} in {degree.subject} ({degree.degreeYear})
                    </div>
                  ))}
                </td>
                <td>
                  {user.addresses.map((address, index) => (
                    <div key={index}>
                      {address.address1}, {address.city}, {address.state} {address.zipCode}
                    </div>
                  ))}
                </td>
                <td>
                  {user.contacts.map((contact, index) => (
                    <div key={index}>
                      {contact.contactNumber} ({contact.contactType})
                    </div>
                  ))}
                </td>
                <td>
                  {user.involvements.join(", ")}
                </td>
                <td>
                  <div className="button-container">
                    <button 
                      className="update-button" 
                      onClick={() => handleUpdateUser(user.id)}
                    >
                      Update
                    </button>
                    <button 
                      className="delete-button" 
                      onClick={() => handleDeleteUser(user.id)}
                    >
                      Delete
                    </button>
                  </div>
                </td>
              </tr>
            ))}
          </tbody>
        </table>
      ) : (
        <p>No results found.</p>
      )}
    </div>
  );
};

export default SearchResults;
